@@ -5,13 +5,15 @@ MEDIA_DIRECTORY = getattr(settings,
                           "BFM_MEDIA_DIRECTORY",
                           settings.MEDIA_ROOT)
 
+MEDIA_URL = getattr(settings, "BFM_MEDIA_URL", '')
+if not MEDIA_URL and MEDIA_DIRECTORY == settings.MEDIA_ROOT:
+    MEDIA_URL = settings.MEDIA_URL
+
 FILES_IN_PAGE = int(getattr(settings,
                         "BFM_FILES_IN_PAGE",
                         20))
 
-MEDIA_URL = getattr(settings, "BFM_MEDIA_URL", '')
-if not MEDIA_URL and MEDIA_DIRECTORY == settings.MEDIA_ROOT:
-    MEDIA_URL = settings.MEDIA_URL
+UPLOADS_AT_ONCE = int(getattr(settings, "BFM_UPLOADS_AT_ONCE", 2))
 
 ADMIN_UPDIR = getattr(settings, "BFM_ADMIN_UPLOAD_DIR", '')
 
@@ -23,4 +25,5 @@ except ImportError:
     HAS_PIL = False
 
 JSON = simplejson.dumps({'files_in_page': FILES_IN_PAGE,
-                        'pil': HAS_PIL})
\ No newline at end of file
+                        'pil': HAS_PIL,
+                        'uploads_at_once': UPLOADS_AT_ONCE})
